/**
 * 项目：互联网医疗
 * 模型分组：服务管理
 * 模型名称：影像报告表
 * @Author: xiongwei
 * @Date: 2023-09-05 09:42:00
 */

package com.xwd.hospital.server.service.impl;

import java.io.Serializable;
import java.util.List;
import java.util.ArrayList;
import java.util.Collection;

import com.xwd.hospital.server.domain.MedicalReportPicture;
import com.xwd.hospital.server.dto.ReportDto;
import com.xwd.hospital.server.service.MedicalReportPictureService;
import jakarta.annotation.Resource;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.xwd.hospital.server.service.MedicalReportService;
import com.xwd.hospital.server.repository.MedicalReportMapper;
import com.xwd.hospital.server.repository.base.MedicalReportBaseMapper;
import com.xwd.hospital.server.domain.MedicalReport;
import com.xwd.hospital.server.rest.req.MedicalReportParam;

@Service
public class MedicalReportServiceImpl extends ServiceImpl<MedicalReportMapper, MedicalReport> implements MedicalReportService {

    @Resource
    private MedicalReportPictureService pictureService;

    @Override
    public int updateAllFieldsById(MedicalReport entity) {
        return this.getBaseMapper().updateAllFieldsById(entity);
    }

    /**
     * 批量插入
     *
     * @param entityList ignore
     * @param batchSize  ignore
     * @return ignore
     */
    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean saveBatch(Collection<MedicalReport> entityList, int batchSize) {
        String sqlStatement = SqlHelper.getSqlStatement(MedicalReportBaseMapper.class, SqlMethod.INSERT_ONE);
        return executeBatch(entityList, batchSize, (sqlSession, entity) -> sqlSession.insert(sqlStatement, entity));
    }

    @Override
    public boolean uploadReport(ReportDto dto) {

        MedicalReport medicalReport = new MedicalReport();
        medicalReport.setAge(dto.getAge());
        medicalReport.setPatientName(dto.getPatientName());
        medicalReport.setReportDoctor(dto.getReportDoctor());
        medicalReport.setReportHospital(dto.getReportHospital());
        medicalReport.setPatientIdNo(dto.getPatientIdNo());
        medicalReport.setSex(dto.getSex());
        medicalReport.setReportItem(dto.getReportItem());
        medicalReport.setReportDeclare(dto.getReportDeclare());
        this.save(medicalReport);

        if(null != dto.getPictureList()
            && dto.getPictureList().size()>0){
            ArrayList<MedicalReportPicture> pictureList = new ArrayList<>();
            for (String picUrl:dto.getPictureList()) {
                MedicalReportPicture picture = new MedicalReportPicture();
                picture.setMedicalReportId(medicalReport.getId());
                picture.setReportPicture(picUrl);
                pictureList.add(picture);
            }
            pictureService.saveBatch(pictureList);
        }

        return true;
    }
}
